Skip to contents

Check a chromosome color map before it reaches igv.js

Usage

.sanitizeChromosomeColorMap(map)

Arguments

map

a named list or character vector of colors, possibly empty

Value

the map as a named list, empty if nothing was supplied