Check a chromosome color map before it reaches igv.js
Source:R/GWASTrack.R
dot-sanitizeChromosomeColorMap.RdCheck a chromosome color map before it reaches igv.js
R/GWASTrack.R
dot-sanitizeChromosomeColorMap.RdCheck a chromosome color map before it reaches igv.js